ParseError

Struct ParseError 

pub struct ParseError {
    pub index: usize,
    pub code: ParseErrorCode,
}
An error encountered when parsing a program from a raw byte buffer.

Fields

index: usize

The index in the provided buffer at which the error occurred.

code: ParseErrorCode

The specific error that occurred.