pub struct TupleCondition {
pub prefix_len: u8,
pub addr: Option<IpAddr>,
pub port: Option<u16>,
}Fields
prefix_len: u8addr: Option<IpAddr>port: Option<u16>Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for TupleCondition
impl<'arbitrary> Arbitrary<'arbitrary> for TupleCondition
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for TupleCondition
impl Clone for TupleCondition
Sourcefn clone(&self) -> TupleCondition
fn clone(&self) -> TupleCondition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TupleCondition
impl Debug for TupleCondition
Sourceimpl PartialEq for TupleCondition
impl PartialEq for TupleCondition
impl Eq for TupleCondition
impl StructuralPartialEq for TupleCondition