UnixResponseHeader

Struct UnixResponseHeader 

pub struct UnixResponseHeader {
    pub kind: u8,
    pub state: u8,
    pub inode: u32,
    pub cookie: [u8; 8],
}
The response to a query for IPv4 or IPv6 sockets

Fields

kind: u8

One of SOCK_PACKET, SOCK_STREAM, or SOCK_SEQPACKET

state: u8

State of the socket. According to man 7 sock_diag it can be either TCP_ESTABLISHED or TCP_LISTEN. However datagram UNIX sockets are not connection oriented so I would assume that this field can also take other value (maybe 0) for these sockets.

inode: u32

Socket inode number.

cookie: [u8; 8]