Bytecode

Struct Bytecode 

pub struct Bytecode(pub Vec<Instruction>);
A bytecode program used by Linux to match AF_INET sockets.

Tuple Fields

0: Vec<Instruction>

Implementations

Source

impl Bytecode

pub fn serialized_len(&self) -> usize

Returns the length of the serialized form of this bytecode.

Useful for sizing the buffer passed to Bytecode::serialize.

pub fn parse(buf: &[u8]) -> Result<Self, ParseError>

Parse a bytecode program from the provided buffer.

pub fn serialize(self, buf: &mut [u8]) -> Result<(), SerializationError>

Serialize the bytecode into the provided buffer.