pub struct Bytecode(pub Vec<Instruction>);Expand description
A bytecode program used by Linux to match AF_INET sockets.
Tuple Fields
0: Vec<Instruction>Implementations
Sourceimpl Bytecode
impl Bytecode
Sourcepub fn serialized_len(&self) -> usize
pub fn serialized_len(&self) -> usize
Returns the length of the serialized form of this bytecode.
Useful for sizing the buffer passed to Bytecode::serialize.
Sourcepub fn parse(buf: &[u8]) -> Result<Self, ParseError>
pub fn parse(buf: &[u8]) -> Result<Self, ParseError>
Parse a bytecode program from the provided buffer.